@@ -33,6 +33,17 @@ class SportNumber(Base):
     def __init__(self, data_list: list):
         self.issue, self.num1, self.num2, self.num3 = data_list
 
+    @classmethod
+    def get_issue_future(cls):
+        """get issue"""
+        session = get_session_sport()
+        i = session.query(cls).all()
+        session.close()
+        last = [x.issue for x in i]
+        last.sort()
+        result = last[-1] + 1
+        return result
+    
     @classmethod
     def get_num1(cls, issue_number: int):
         """获取对应 issue 的号码 num1"""
@@ -814,6 +825,17 @@ class SportNumber5(Base):
     def __init__(self, data_list: list):
         self.issue, self.num1, self.num2, self.num3, self.num4, self.num5 = data_list
 
+    @classmethod
+    def get_issue_future(cls):
+        """get issue"""
+        session = get_session_sport()
+        i = session.query(cls).all()
+        session.close()
+        last = [x.issue for x in i]
+        last.sort()
+        result = last[-1] + 1
+        return result
+    
     @classmethod
     def get_issues(cls):
         """get issues[list]"""
