@@ -1,5 +1,5 @@
 from sqlalchemy import Column, String, Integer, Float
-from sqlalchemy.ext.declarative import declarative_base
+from sqlalchemy.orm import declarative_base
 from sqlalchemy_sqlite_session.tools import get_engine, get_session
 import json
 
